django-ulogin
=============


.. image:: https://badge.fury.io/py/django-ulogin.png
    :target: http://badge.fury.io/py/django-ulogin
    :alt:

.. image:: https://travis-ci.org/marazmiki/django-ulogin.png?branch=master

.. image:: https://coveralls.io/repos/marazmiki/django-ulogin/badge.png?branch=master
    :target: https://coveralls.io/r/marazmiki/django-ulogin?branch=master
    :alt: Code coverage percentage

.. image:: https://readthedocs.org/projects/django-ulogin/badge/?version=latest
    :target: https://django-ulogin.readthedocs.io/ru/latest/?badge=latest
    :alt: Documentation Status
                



Описание
--------

**django-ulogin** — подключаемое универсальное django-приложение для социальной аутентификации пользователей с помощью внешнего интернет-сервиса `uLogin <https://ulogin.ru>`_


.. attention::
    Создатели приложения никак не связаны с интернет-сервисом `uLogin <https://ulogin.ru>`_, поэтому все вопросы, касающиеся непосредственно работы сервиса, а не этого приложения, просьба отправлять на `team@ulogin.ru <team@ulogin.ru>`_.


Подробная документация проекта доступна на `Read the Docs <https://django-ulogin.readthedocs.org/>`_.
